@@ -1,7 +1,7 @@
-from sylenium.configuration.sylenium_configuration import syleniumConfiguration
+from sylenium.configuration.configuration import Configuration
 
 
-class HeadlessConfig(syleniumConfiguration):
+class HeadlessConfig(Configuration):
     def __init__(self):
         super().__init__(
             headless=True,
